==> wls-plugin-3.0.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsSubdeploymentStep.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import java.util.List;
import java.util.Set;

import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsServer;
import com.xebialabs.deployit.plugin.wls.mapper.JmsMapperUtils;

@SuppressWarnings("serial")
public class CreateWlsSubdeploymentStep extends SimpleWlstExecutingStep {
	private static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-subdeployment.py";

	public CreateWlsSubdeploymentStep(WlsDomain domain, String jmsModuleName, WlsJmsServer jmsServer) {
		this(domain, jmsModuleName, Sets.newHashSet(jmsServer));
	}
	
	public CreateWlsSubdeploymentStep(WlsDomain domain, String jmsModuleName, Set<WlsJmsServer> jmsServers) {
		super("Create Subdeployment " + JmsMapperUtils.getSubdeploymentName(jmsModuleName, jmsServers) + " in module " + jmsModuleName + " targeted at JMS servers " + jmsServers
				+ " on domain " + domain, domain, SCRIPT_RESOURCE_PATH, getArgs(jmsModuleName, jmsServers));
	}
	
	private static String[] getArgs(String jmsModuleName, Set<WlsJmsServer> jmsServers) {
		List<String> args = Lists.newArrayList();
		args.add(JmsMapperUtils.getSubdeploymentName(jmsModuleName, jmsServers));
		args.add(jmsModuleName);
		for (WlsJmsServer jmsServer : jmsServers) {
			args.add(jmsServer.getName());
		}
		return args.toArray(new String[args.size()]);
	}
}

==> wls-plugin-3.0.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsSubdeploymentStep.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import java.util.List;
import java.util.Set;

import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import com.xebialabs.deployit.hostsession.CmdLineArgument;
import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsServer;
import com.xebialabs.deployit.plugin.wls.mapper.JmsMapperUtils;

@SuppressWarnings("serial")
public class CreateWlsSubdeploymentStep extends SimpleWlstExecutingStep {
	private static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-subdeployment.py";

	public CreateWlsSubdeploymentStep(WlsDomain domain, String jmsModuleName, WlsJmsServer jmsServer) {
		this(domain, jmsModuleName, Sets.newHashSet(jmsServer));
	}
	
	public CreateWlsSubdeploymentStep(WlsDomain domain, String jmsModuleName, Set<WlsJmsServer> jmsServers) {
		super("Create Subdeployment " + JmsMapperUtils.getSubdeploymentName(jmsModuleName, jmsServers) + " in module " + jmsModuleName + " targeted at JMS servers " + jmsServers
				+ " on domain " + domain, domain, SCRIPT_RESOURCE_PATH, getArgs(jmsModuleName, jmsServers));
	}
	
	private static List<CmdLineArgument> getArgs(String jmsModuleName, Set<WlsJmsServer> jmsServers) {
		List<CmdLineArgument> args = Lists.newArrayList();
		args.add(CmdLineArgument.arg(JmsMapperUtils.getSubdeploymentName(jmsModuleName, jmsServers)));
		args.add(CmdLineArgument.arg(jmsModuleName));
		for (WlsJmsServer jmsServer : jmsServers) {
			args.add(CmdLineArgument.arg(jmsServer.getName()));
		}
		return args;
	}
}
